# Dropship Change Log

We are currently in a pre-alpha design & development phase. Therefore, we're
not using [semver](https://semver.org/) yet and iterating on `0.0.X` versioning
(e.g. `0.0.4`, `0.0.5`, `0.0.6`, etc.). At this stage, we expect everything to
change so expect breaking changes. However, later on, we will maintain a sane
versioning policy to indicate breaking changes.

## dropship 0.0.5 (2020-10-13)

- Initial super-pre-alpha early testers release.

## dropship < 0.0.5

- No change log, too much hacking!
